-- This file includes stored procedures that have to be modified to be compatible with SQLServer 2000


USE [WaspTrackAsset]

if EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SpUpdateUserAccountSetting]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SpUpdateUserAccountSetting]
GO


SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

-- =============================================
-- Author:		Christina YE
-- Create date: 5/1/2010
-- Description:	Create a new user account and all associated rights 
-- Modify date: 09/10/2010        -- Mary Fu
-- Modification Reason: To be compatible with SQLServer 2000, not to use TRY ... CATCH ... 
-- =============================================

CREATE PROCEDURE [dbo].[SpUpdateUserAccountSetting]	
	@last_name nvarchar(50), 
	@first_name nvarchar(50),
	@title nvarchar(50),
	@department nvarchar(20),
	@manager nvarchar(50), 
	@user_login nvarchar(20), 
	@user_pwd wtpassword,
	@changepasswd wtbool, 
	@email nvarchar(250), 
	@group_id int,
	@userid int output
AS

BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	
	if (SELECT count(*) FROM users WHERE user_logon = @user_login and group_id = @group_id and company_id = 1 and record_status = 1) =  0
	BEGIN 
			
		INSERT INTO [dbo].[users]
		   ([last_name]
		   ,[first_name]
		   ,[title]
		   ,[department]
		   ,[manager]
		   ,[user_logon]
		   ,[user_password]
		   ,[changed_password]
		   ,[email]
		   ,[record_status]
		   ,[company_id]
		   ,[date_updated]
		   ,[group_id])
		VALUES
		   (@last_name
		   ,@first_name
		   ,@title
		   ,@department
		   ,@manager
		   ,@user_login
		   ,@user_pwd
		   ,@changepasswd
		   ,@email
		   ,1
		   ,1
		   ,GetDate()
		   ,@group_id)
       
	END 

	-- when no BEGION TREANSACTION is used in a stored procedure, everything is treated as one transaction 
	-- when all statements are success, transactions will be commit, otherwise transactions will be rollback 
	-- at the end of stored procedure
	set @userid = (select user_id from users where user_logon = @user_login and group_id = @group_id and company_id = 1 and record_status = 1)
	DELETE FROM [dbo].[user_privileges] where user_id = @userid

	DELETE FROM dbo.user_site where user_id = @userid

	INSERT INTO [dbo].[user_privileges]
		select @userid, security_code, record_status from dbo.user_group_privileges where group_id = @group_id and record_status = 1 and company_id = 1

	INSERT INTO [dbo].[user_site]
		SELECT @userid, site_id FROM dbo.user_group_sites where group_id = @group_id

END
GO

